@@ -9,7 +9,7 @@
 #' @inheritParams get_response
 #' @inheritParams find_formula
 #'
-#' @return The number of observations used to fit the model, or \code{NULL} if
+#' @return The number of observations used to fit the model, or `NULL` if
 #'   this information is not available.
 #'
 #' @examples
@@ -334,6 +334,7 @@ n_obs.gbm <- function(x, ...) {
 #' @rdname n_obs
 #' @inheritParams get_data
 n_obs.afex_aov <- function(x, shape = c("long", "wide"), ...) {
+  shape <- match.arg(shape)
   nrow(get_data(x, shape = shape))
 }
 
