@@ -1,6 +1,6 @@
-if (require("testthat") &&
-  require("insight") &&
-  require("cplm")) {
+if (requiet("testthat") &&
+  requiet("insight") &&
+  requiet("cplm")) {
   data("FineRoot")
   m1 <- cpglmm(RLD ~ Stock + Spacing + (1 | Plant), data = FineRoot)
 
