@@ -1,4 +1,4 @@
-if (require("testthat") && require("insight")) {
+if (requiet("testthat") && requiet("insight")) {
   d <- data.frame(CI = 0.97, CI_low = 1, CI_high = 3)
   test_that("format_table with ci-level", {
     ft <- insight::format_table(d)
