@@ -1,6 +1,6 @@
-if (require("testthat") &&
-  require("insight") &&
-  require("glmmTMB")) {
+if (requiet("testthat") &&
+  requiet("insight") &&
+  requiet("glmmTMB")) {
   # fish <- read.csv("https://stats.idre.ucla.edu/stat/data/fish.csv")
   # fish$nofish <- as.factor(fish$nofish)
   # fish$livebait <- as.factor(fish$livebait)
@@ -866,4 +866,39 @@ if (require("testthat") &&
       c("conditional", "conditional", "dispersion", "dispersion")
     )
   })
+
+ test_that("get_predicted", {
+
+    # response
+    x <- get_predicted(m1, predict = "expectation", verbose = FALSE)
+    y <- get_predicted(m1, predict = NULL, type = "response")
+    z <- predict(m1, type = "response")
+    # expect_equal(x, y, ignore_attr = TRUE)
+    # expect_equal(x, z, ignore_attr = TRUE)
+    expect_equal(y, z, ignore_attr = TRUE)
+
+    # link
+    x <- get_predicted(m1, predict = "link")
+    y <- get_predicted(m1, predict = NULL, type = "link")
+    z <- predict(m1, type = "link")
+    expect_equal(x, y, ignore_attr = TRUE)
+    expect_equal(y, z, ignore_attr = TRUE)
+    expect_equal(x, z, ignore_attr = TRUE)
+
+    # unsupported: zprob
+    x <- suppressWarnings(get_predicted(m1, predict = "zprob"))
+    y <- get_predicted(m1, predict = NULL, type = "zprob")
+    z <- predict(m1, type = "zprob")
+    expect_equal(x, y)
+    expect_equal(x, z, ignore_attr = TRUE)
+
+    # not official supported raise warning
+    expect_warning(get_predicted(m1, predict = "zprob"))
+    expect_warning(get_predicted(m1, predict = "zprob", verbose = FALSE), NA)
+    # the second warning is raised for zero-inflation models only. remove when
+    # the zprob correction is implemented
+    expect_warning(expect_warning(get_predicted(m1, predict = "prediction")))
+    expect_warning(expect_warning(get_predicted(m1, predict = "classification")))
+  })
+
 }
