@@ -1,6 +1,6 @@
-if (require("testthat") &&
-  require("insight") &&
-  require("robustbase")) {
+if (requiet("testthat") &&
+  requiet("insight") &&
+  requiet("robustbase")) {
   data(carrots)
 
   m1 <- glmrob(
@@ -94,7 +94,7 @@ if (require("testthat") &&
   })
 
   test_that("n_obs", {
-    expect_equal(n_obs(m1), 24)
+    expect_equal(n_obs(m1), 900)
   })
 
   test_that("link_function", {
