@@ -2,10 +2,10 @@
 .runStanTest <- Sys.getenv("RunAllinsightStanTests") == "yes"
 
 if (.runThisTest && .runStanTest) {
-  if (suppressWarnings(require("testthat") &&
-    require("insight") && require("lme4") &&
-    require("BayesFactor") &&
-    require("rstanarm"))) {
+  if (suppressWarnings(requiet("testthat") &&
+    requiet("insight") && requiet("lme4") &&
+    requiet("BayesFactor") &&
+    requiet("rstanarm"))) {
 
     # skip_on_cran()
 
